@@ -5,13 +5,14 @@ use warnings;
 
     BEGIN {
         use version qw[qv];
-        our $SVN = q[$Id: Peer.pm 23 2008-06-18 02:35:47Z sanko@cpan.org $];
-        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 23 $)->numify / 1000;
+        our $SVN = q[$Id: Peer.pm 25 2008-07-02 03:07:52Z sanko@cpan.org $];
+        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 25 $)->numify / 1000;
     }
     use Socket
         qw[SOL_SOCKET SO_SNDTIMEO SO_RCVTIMEO PF_INET AF_INET SOCK_STREAM];
     use Fcntl qw[F_SETFL O_NONBLOCK];
     use Digest::SHA qw[sha1_hex];
+    use Errno qw[EINPROGRESS EWOULDBLOCK];
     use lib q[../../../../lib/];
     use Net::BitTorrent::Session::Peer::Request;
     use Net::BitTorrent::Util qw[min :bencode :log compact];
@@ -67,21 +68,48 @@ use warnings;
         {
 
             # perldoc perlipc
-            socket(my ($socket), PF_INET, SOCK_STREAM, getprotobyname(q[tcp]))
-                or next PORT;
-            if ($^O eq q[MSWin32]) {
-                ioctl($socket, 0x8004667e, pack(q[I], 1));
-            }
-            else { fcntl($socket, F_SETFL, O_NONBLOCK) }
-            my ($ip, $peerport) = split q[:], $args->{q[address]}, 2;
-            connect($socket,
-                    pack(q[Sna4x8],
-                         AF_INET, $peerport,
-                         join(q[], map { chr $_ } ($ip =~ m[(\d+)]g)))
-            );
-
-            # TODO: check value of err to verify non-blocking connect
             $self = bless \$args->{q[address]}, $class;
+            my $socket;
+            if (not CORE::socket($socket,     PF_INET,
+                                 SOCK_STREAM, getprotobyname(q[tcp]))
+                )
+            {   $self->_disconnect(q[Failed to create socket]);
+                return;
+            }
+            if (not($^O eq q[MSWin32]
+                    ? ioctl($socket, 0x8004667e, pack(q[I], 1))
+                    : fcntl($socket, F_SETFL, O_NONBLOCK)
+                )
+                )
+            {   $self->_disconnect(q[Failed to set socket to non-blocking]);
+                return;
+            }
+            if (not setsockopt($socket, SOL_SOCKET,
+                               SO_SNDTIMEO, pack('LL', 15, 0))
+                or not setsockopt($socket, SOL_SOCKET,
+                                  SO_RCVTIMEO, pack('LL', 15, 0))
+                )
+            {   $self->_disconnect(
+                                  q[Failed to set socket connection timeout]);
+                return;
+            }
+            my ($ip, $peerport) = split q[:], $args->{q[address]}, 2;
+            if (not connect($socket,
+                            pack(q[Sna4x8],
+                                 AF_INET,
+                                 $peerport,
+                                 join(q[], map { chr $_ } ($ip =~ m[(\d+)]g)))
+                )
+                and $^E
+                and ($^E != EINPROGRESS)
+                and ($^E != EWOULDBLOCK)
+                )
+            {   $self->_disconnect(sprintf q[Failed to connect: %s (%d)],
+                                   $^E, $^E + 0);
+                return;
+            }
+
+            # everything's good, let's keep moving.
             $socket{$self}              = $socket;
             $fileno{$self}              = fileno($socket{$self});
             $connected{$self}           = 0;
@@ -119,29 +147,26 @@ use warnings;
         $client{$self}->_set_pulse($self, time + 5);
         return 1;
     }
-    sub _get_fileno    { die if $_[1]; return $fileno{$_[0]}; }
-    sub get_session    { die if $_[1]; return $session{$_[0]}; }
-    sub _get_connected { die if $_[1]; return $connected{$_[0]}; }
+    sub _get_fileno    { return $fileno{$_[0]}; }
+    sub get_session    { return $session{$_[0]}; }
+    sub _get_connected { return $connected{$_[0]}; }
 
     sub _get_connection_timestamp {
-        die if $_[1];
         return $connection_timestamp{$_[0]};
     }
-    sub _get_queue_outgoing { die if $_[1]; return $queue_outgoing{$_[0]}; }
-    sub _get_socket         { die if $_[1]; return $socket{$_[0]}; }
-    sub get_peer_id         { die if $_[1]; return $peer_id{$_[0]}; }
-    sub get_client          { die if $_[1]; return $client{$_[0]}; }
-    sub get_bitfield        { die if $_[1]; return $bitfield{$_[0]}; }
-    sub get_is_choking      { die if $_[1]; return $is_choking{$_[0]}; }
+    sub _get_queue_outgoing { return $queue_outgoing{$_[0]}; }
+    sub _get_socket         { return $socket{$_[0]}; }
+    sub get_peer_id         { return $peer_id{$_[0]}; }
+    sub get_client          { return $client{$_[0]}; }
+    sub get_bitfield        { return $bitfield{$_[0]}; }
+    sub get_is_choking      { return $is_choking{$_[0]}; }
 
     sub get_outgoing_requests {
-        die if $_[1];
         return $outgoing_requests{$_[0]};
     }
 
     sub get_peerhost {    # cache it
         my ($self) = @_;
-        die if $_[1];
         if (not defined $peerhost{$self}
             and $connected{$self})
         {   my (undef, undef, @address)
@@ -153,7 +178,6 @@ use warnings;
 
     sub get_peerport {    # cache it
         my ($self) = @_;
-        die if $_[1];
         if (not defined $peerport{$self}
             and $connected{$self})
         {   (undef, $peerport{$self}, undef)
@@ -236,6 +260,10 @@ use warnings;
                                              [caller 0]->[3], $$self
                                      )
         );
+        if (not $socket{$self} || not defined $socket{$self}) {
+            $self->_disconnect;
+            return;
+        }
         my $actual_read =
             sysread($socket{$self},
                     $queue_incoming{$self},
@@ -268,6 +296,10 @@ use warnings;
                                              [caller 0]->[3], $$self
                                      )
         );
+        if (not $socket{$self} || not defined $socket{$self}) {
+            $self->_disconnect;
+            return;
+        }
         my $actual_write =
             syswrite($socket{$self},
                      substr($queue_outgoing{$self}, 0, $length, q[]),
@@ -287,7 +319,7 @@ use warnings;
                                              [caller 0]->[3], $$self
                                      )
         );
-        close $socket{$self};
+        close $socket{$self} if $socket{$self};
         $client{$self}->_remove_connection($self);
         $reason ||= q[Connection closed by remote peer.];
         $client{$self}->_do_callback(q[peer_disconnect], $self, $reason);
@@ -448,24 +480,22 @@ use warnings;
                 = unpack q[Na] . ($packet_len) . q[ a*],
                 $queue_incoming{$self};
             ($type, my $packet) = unpack(q[ca*], $packet_data);
-            my %dispatch = (
-                q[] => \&_parse_packet_keepalive,
-                0   => \&_parse_packet_choke,
-                1   => \&_parse_packet_unchoke,
-                2   => \&_parse_packet_interested,
-                3   => \&_parse_packet_disinterested,
-                4   => \&_parse_packet_have,
-                5   => \&_parse_packet_bitfield,
-                6   => \&_parse_packet_request,
-                7   => \&_parse_packet_piece,
-                8   => \&_parse_packet_cancel,
-                9   => \&_parse_packet_port,
-                14  => \&_parse_packet_have_all,
-                15  => \&_parse_packet_have_none,
-
-                #16 => \&_parse_packet_reject,
-                #17 => \&_parse_packet_allowed_fast,
-                20 => \&_parse_packet_extended
+            my %dispatch = (q[] => \&_parse_packet_keepalive,
+                            0   => \&_parse_packet_choke,
+                            1   => \&_parse_packet_unchoke,
+                            2   => \&_parse_packet_interested,
+                            3   => \&_parse_packet_disinterested,
+                            4   => \&_parse_packet_have,
+                            5   => \&_parse_packet_bitfield,
+                            6   => \&_parse_packet_request,
+                            7   => \&_parse_packet_piece,
+                            8   => \&_parse_packet_cancel,
+                            9   => \&_parse_packet_port,
+                            14  => \&_parse_packet_have_all,
+                            15  => \&_parse_packet_have_none,
+                            16  => \&_parse_packet_reject,
+                            17  => \&_parse_packet_allowed_fast,
+                            20  => \&_parse_packet_extended
             );
             if (defined $dispatch{$type}) {
                 %ref = $dispatch{$type}($self, $packet_len, $packet);
@@ -473,7 +503,9 @@ use warnings;
             else {
                 if (require Data::Dumper) {
                     warn $type;
-                    warn Data::Dumper::Dump($packet);
+                    warn q[Unhandled BitTorrent packet: ]
+                        . Data::Dumper->Dump([$type, $packet],
+                                             [qw[type infohash]]);
                 }
 
                 # XXX - think about banning this guy
@@ -938,7 +970,7 @@ use warnings;
                 #
                 #}
                 #elsif (not scalar $block->get_peers
-                #    or not $block->request_timestamp($self))
+                #    or not $block->get_request_timestamp($self))
                 #{
                 # TODO: ...should we accept the block anyway if we need it?
                 $self->_disconnect(
@@ -1260,7 +1292,7 @@ use warnings;
         }
         else {
 
-            #die;
+            #
         }
         return;
     }
@@ -1327,18 +1359,17 @@ use warnings;
         }
         return $_fastset_out{$self} = \@a;
     }
-    sub get_downloaded { die if $_[1]; return $downloaded{$_[0]}; }
-    sub get_is_choked  { die if $_[1]; return $is_choked{$_[0]}; }
+    sub get_downloaded { return $downloaded{$_[0]}; }
+    sub get_is_choked  { return $is_choked{$_[0]}; }
 
     sub get_incoming_connection {
-        die if $_[1];
         return $incoming_connection{$_[0]};
     }
-    sub get_is_interested   { die if $_[1]; return $is_interested{$_[0]}; }
-    sub get_is_interesting  { die if $_[1]; return $is_interesting{$_[0]}; }
-    sub get_reserved        { die if $_[1]; return $reserved{$_[0]}; }
-    sub get_uploaded        { die if $_[1]; return $uploaded{$_[0]}; }
-    sub _get_queue_incoming { die if $_[1]; return $queue_incoming{$_[0]}; }
+    sub get_is_interested   { return $is_interested{$_[0]}; }
+    sub get_is_interesting  { return $is_interesting{$_[0]}; }
+    sub get_reserved        { return $reserved{$_[0]}; }
+    sub get_uploaded        { return $uploaded{$_[0]}; }
+    sub _get_queue_incoming { return $queue_incoming{$_[0]}; }
 
 #     sub _build_packet_port {
 #~         my ($self) = @_;
@@ -1548,6 +1579,6 @@ Noncommercial-Share Alike 3.0 License
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Peer.pm 23 2008-06-18 02:35:47Z sanko@cpan.org $
+=for svn $Id: Peer.pm 25 2008-07-02 03:07:52Z sanko@cpan.org $
 
 =cut
